Block requests for untrusted URLs with status
authorFabian Keil <fk@fabiankeil.de>
Thu, 31 Aug 2006 10:55:49 +0000 (10:55 +0000)
committerFabian Keil <fk@fabiankeil.de>
Thu, 31 Aug 2006 10:55:49 +0000 (10:55 +0000)
code 403 instead of 200.

filters.c

index 7eb6733..1a1da40 100644 (file)
--- a/filters.c
+++ b/filters.c
@@ -1,4 +1,4 @@
-const char filters_rcs[] = "$Id: filters.c,v 1.62 2006/08/14 00:27:47 david__schmidt Exp $";
+const char filters_rcs[] = "$Id: filters.c,v 1.63 2006/08/31 10:11:28 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/filters.c,v $
@@ -39,6 +39,11 @@ const char filters_rcs[] = "$Id: filters.c,v 1.62 2006/08/14 00:27:47 david__sch
  *
  * Revisions   :
  *    $Log: filters.c,v $
+ *    Revision 1.63  2006/08/31 10:11:28  fabiankeil
+ *    Don't free p which is still in use and will be later
+ *    freed by free_map(). Don't claim the referrer is unknown
+ *    when the client didn't set one.
+ *
  *    Revision 1.62  2006/08/14 00:27:47  david__schmidt
  *    Feature request 595948: Re-Filter logging in single line
  *
@@ -968,7 +973,7 @@ struct http_response *block_url(struct client_state *csp)
  * Function    :  trust_url FIXME: I should be called distrust_url
  *
  * Description :  Calls is_untrusted_url to determine if the URL is trusted
*                and if not, returns a HTTP 304 response with a reject message.
  *
  * Parameters  :
  *          1  :  csp = Current client state (buffers, headers, etc...)
@@ -1002,8 +1007,9 @@ struct http_response *trust_url(struct client_state *csp)
       return cgi_error_memory();
    }
 
+   rsp->status = strdup("403 Request blocked by Privoxy");
    exports = default_exports(csp, NULL);
-   if (exports == NULL)
+   if (exports == NULL || rsp->status == NULL)
    {
       free_http_response(rsp);
       return cgi_error_memory();
@@ -968,7 +973,7 @@ struct http_response *block_url(struct client_state *csp)
  *
  * Description :  Calls is_untrusted_url to determine if the URL is trusted
- *                and if not, returns a HTTP 304 response with a reject message.
+ *                and if not, returns a HTTP 403 response with a reject message.
  *
  * Parameters  :